package com.anyway.favor.controller;

import com.anyway.favor.model.Favor;
import com.anyway.favor.model.User;
import com.anyway.favor.model.dto.FavorDto;
import com.anyway.favor.service.FavorService;
import com.anyway.util.PageQuery;
import com.anyway.util.R;
import com.anyway.util.SessionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 人情控制器
 *
 * @author liuchuanwei
 * @date 2024-02-24
 */
@RestController
@RequestMapping("/favor")
public class FavorController {
    @Autowired
    private FavorService favorService;

    /**
     * 添加人情
     *
     * @param favorAddDto
     * @return
     */
    @PostMapping("/add")
    public R<Boolean> add(@RequestBody @Validated FavorDto favorAddDto) {
        User currentUser = SessionUtils.currentUser();
        favorAddDto.setCreateBy(currentUser.getId());
        return favorService.add(favorAddDto) ? R.ok() : R.fail("新增失败");
    }

    /**
     * 更新人情
     *
     * @param favorAddDto
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> update(@RequestBody @Validated FavorDto favorAddDto) {
        if (favorAddDto.getId() == null) {
            return R.fail("人情事件ID不能为空");
        }
        User currentUser = SessionUtils.currentUser();
        favorAddDto.setModifyBy(currentUser.getId());
        return favorService.update(favorAddDto) ? R.ok() : R.fail("保存失败");
    }

    /**
     * 人情事件列表
     *
     * @param pageQuery
     * @return
     */
    @GetMapping("/listPage")
    public R<List<Favor>> listPage(@RequestBody PageQuery<Map<String, Object>> pageQuery) {
        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = pageQuery.getTerms(new HashMap<>());
        //查询和当前登录用户相关的人员
        mapCondition.put("createBy", currentUser.getId());
        List<Favor> favorList = favorService.findPage(pageQuery);
        return R.page(favorList, pageQuery.getPage());
    }

    /**
     * 人情事件详情
     *
     * @return
     */
    @GetMapping("/detail/{id}")
    public R<FavorDto> detail(@PathVariable Long id) {
        return R.data(favorService.findDetail(id));
    }

    /**
     * 删除
     *
     * @param id
     * @return
     */
    @PostMapping("/delete/{id}")
    public R<Boolean> delete(@PathVariable Long id) {
        boolean b = favorService.deleteById(id);
        return b ? R.ok() : R.fail("删除失败");
    }

}
